unit uCartaBasico;

interface

{$RESOURCE 'CARTAS_FIGURAS.RES'}

uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs;

const
  LARGURA_CARTA  = 71;
  ALTURA_CARTA = 96;

var
  bmpCartaNeutra: TBitmap;
  bmpCarta: TBitmap;

type

  TBaralho =
    (baAs, baDois, baTres, baQuatro, baCinco, baSeis, baSete, baOito,
     baNove, baDez, baValete, baDama, baRei, baCuringa);

  TNaipe = (naPaus, naOuro, naCoracao, naEspada);

  TCartaBasico = class(TGraphicControl)
  private
    { Private declarations }
  protected
    FCartaAtual: Integer;
    FSuite: Integer;
    FExibir: Boolean;
    FSelecionada: Boolean;
    FModoPintura: Integer;
    procedure Paint; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;

    procedure SetBounds(ALeft, ATop, AWidth, AHeight: Integer); override;

    procedure SetCartaAtual(pValor: Integer); virtual;
    procedure SetExibir(pValor: Boolean); virtual;
    procedure SetSuite(pValor: Integer); virtual;
    procedure SetSelecionada(pValor: Boolean); virtual;

    property CartaAtual: Integer read FCartaAtual write SetCartaAtual;
    property Suite: Integer read FSuite write SetSuite;
  published
    property Selecionada: Boolean read FSelecionada write SetSelecionada;
    property Exibir: Boolean read FExibir write SetExibir;

    property DragMode;

    property OnClick;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnEndDrag;
    property OnMouseMove;
    property OnMouseDown;
    property OnMouseUp;
  end;

implementation

constructor TCartaBasico.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);

  FCartaAtual := 0;
  FModoPintura := 0;
end;

destructor TCartaBasico.Destroy;
begin
  inherited Destroy;
end;

procedure TCartaBasico.SetBounds(ALeft, ATop, AWidth, AHeight: Integer);
begin
  inherited SetBounds(ALeft, ATop, LARGURA_CARTA, ALTURA_CARTA);
end;

procedure TCartaBasico.Paint;
begin
  BitBlt(bmpCarta.Canvas.Handle, 0, 0, LARGURA_CARTA, ALTURA_CARTA,
    Canvas.Handle, 0, 0, SRCCOPY);
  if (not FSelecionada) then
  begin
    BitBlt(bmpCarta.Canvas.Handle, 0, 0, LARGURA_CARTA, ALTURA_CARTA,
      bmpCartaNeutra.Canvas.Handle, 0, 0, SRCAND);
    FModoPintura := SRCPAINT;
  end
  else
  begin
    BitBlt(bmpCarta.Canvas.Handle, 0, 0, LARGURA_CARTA, ALTURA_CARTA,
      bmpCartaNeutra.Canvas.Handle, 0, 0, SRCERASE);
    FModoPintura := NOTSRCERASE;
  end;
end;

procedure TCartaBasico.SetCartaAtual(pValor: Integer);
begin
  FCartaAtual := pValor;
  if FExibir then
    Repaint;
end;

procedure TCartaBasico.SetSelecionada(pValor: Boolean);
begin
  if (FSelecionada <> pValor) then
  begin
    FSelecionada := pValor;
    Repaint;
  end;
end;

procedure TCartaBasico.SetExibir(pValor: Boolean);
begin
  if (FExibir <> pValor) then
  begin
    FExibir := pValor;
    Repaint;
  end;
end;

procedure TCartaBasico.SetSuite(pValor: Integer);
begin
  FSuite := pValor;
  if FExibir then
    Repaint;
end;

initialization

  if (not Assigned(bmpCartaNeutra)) then
  begin
    bmpCartaNeutra := TBitmap.Create;
    bmpCartaNeutra.Monochrome := True;
    bmpCartaNeutra.LoadFromResourceName(HInstance, 'CARTA_NEUTRA');
  end;

  if (not Assigned(bmpCarta)) then
  begin
    bmpCarta := TBitmap.Create;
    bmpCarta.Width := LARGURA_CARTA;
    bmpCarta.Height := ALTURA_CARTA;
  end;

finalization

  if (Assigned(bmpCartaNeutra)) then
    FreeAndNil(bmpCartaNeutra);

  if (Assigned(bmpCarta)) then
    FreeAndNil(bmpCarta);

end.

