
/*Criao das Tabelas*/

CREATE TABLE INGREDIENTE (
    ID       INTEGER NOT NULL,
    NOME     VARCHAR(50),
    UNIDADE  VARCHAR(10),
    PRECO    DECIMAL(10,2),
    CONSTRAINT PK_INGREDIENTE PRIMARY KEY(ID)
);

CREATE TABLE RESPONSAVEL (
    ID          INTEGER NOT NULL,
    NOME        VARCHAR(100),
    TELEFONE    VARCHAR(10),
    EMAIL       VARCHAR(75),
    DTCADASTRO  DATE,
    ISUSER      CHAR(10) DEFAULT '0',
    LOGIN       VARCHAR(25),
    SENHA       VARCHAR(25),
    CONSTRAINT PK_RESPONSAVEL PRIMARY KEY(ID)
);

CREATE TABLE RECEITA (
    ID           INTEGER NOT NULL,
    DESCRICAO    VARCHAR(100),
    DTCADASTRO   DATE,
    QUANTIDADE   INTEGER,
    CATEGORIA    VARCHAR(30),
    PREPARO      VARCHAR(9999),
    OBS          VARCHAR(9999),
    RESPONSAVEL  INTEGER,
    CONSTRAINT PK_RECEITA  PRIMARY KEY(ID),
    CONSTRAINT FK_RECEITA_RESPONSAVEL FOREIGN KEY (RESPONSAVEL) REFERENCES RESPONSAVEL (ID)    
);

CREATE TABLE RECEITAFINAL (
    ID               INTEGER NOT NULL,
    INGREDIENTES_ID  INTEGER,
    RECEITA_ID       INTEGER,
    CONSTRAINT PK_RECEITAFINAL  PRIMARY KEY(ID),
    CONSTRAINT FK_RECEITAFINAL_INGREDIENTE FOREIGN KEY (INGREDIENTES_ID) REFERENCES INGREDIENTE (ID),
    CONSTRAINT FK_RECEITAFINAL_RECEITA FOREIGN KEY (RECEITA_ID) REFERENCES RECEITA (ID)
);

/*Generator*/
CREATE GENERATOR GEN_INGREDIENTE_ID;
CREATE GENERATOR GEN_RECEITA_ID;
CREATE GENERATOR GEN_RESPONSAVEL_ID;
CREATE GENERATOR GEN_RECEITAFINAL_ID;

/*Triggers*/

CREATE TRIGGER INGREDIENTE_BI FOR INGREDIENTE
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(GEN_INGREDIENTE_ID,1);
END;

CREATE TRIGGER RECEITA_BI FOR RECEITA
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(GEN_RECEITA_ID,1);
END;

CREATE TRIGGER RESPONSAVEL_BI FOR RESPONSAVEL
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(GEN_RESPONSAVEL_ID,1);
END;

CREATE TRIGGER RECEITAFINAL_BI FOR RECEITAFINAL
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(GEN_RECEITAFINAL_ID,1);
END;
